---
title: PayPal(페이팔) Standard checkout(SPB) 서비스 오픈
category: 공지사항
tags:
  - 페이팔
  - 공지사항
pgCompanies:
  - 페이팔
datetime: 2024-03-18T10:02:37.923Z
---

<Callout title="Smart Payment Buttons(SPB) 방식은" content="- PayPal 회원 결제 +비회원 결제 와 함께 각 국가별 유명 간편결제(Bancontact, BLIK 등),
할부 결제(Pay Later) 추가로 지원하고 있습니다.
- 구매자 결제 편의성 증대 및 결제 전환율 향상을 기대 할 수 있습니다. " />

### 페이팔 SPB 버튼 렌더링

- 페이팔 SPB 일반결제는 고객사 주문 페이지에 페이팔 SPB 버튼(아래 이미지 참고)을 렌더링 한 후, 이 SPB 버튼을 클릭해 페이팔 결제창을 호출하는 방식입니다.

![](/uploads/페이팔.png)

※ 기존에 제공되던 Paypal Express checkout 신규 신청 및 신규 연동이 불가 합니다.신규 연동 필요 시 아래 가이드 참고 부탁드립니다.

<연동가이드>

☞ [페이팔 SPB(Smart Payment Buttons) 연동 방법 보러가기 ↗](https://developers.portone.io/opi/ko/integration/pg/v1/spb/readme?v=v1)

☞ [페이팔(paypal) 결제 특징 보러가기 ↗ ](https://guide.portone.io/bc611220-a885-485a-b4ee-184a4e73c99b)
